@@ -721,9 +721,10 @@ omopTables <- function(version = "5.3") {
 #' have.
 #'
 #' @param table Table to see required columns.
+#' @param required Whether to include only required fields.
 #' @param version Version of the OMOP Common Data Model.
 #'
-#' @return Required columns
+#' @return Character vector with the column names
 #'
 #' @export
 #'
@@ -732,10 +733,11 @@ omopTables <- function(version = "5.3") {
 #'
 #' omopColumns("person")
 #'
-omopColumns <- function(table, version = "5.3") {
+omopColumns <- function(table, required = TRUE, version = "5.3") {
   assertVersion(version = version)
   assertTable(table = table, version = version, type = "cdm_table")
-  requiredColumns(table = table, version = version, type = "cdm_table")
+  assertLogical(x = required, length = 1)
+  getColumns(table = table, version = version, type = "cdm_table", required = required)
 }
 
 #' Cohort tables that a cdm reference can contain in the OMOP Common Data
@@ -760,8 +762,11 @@ cohortTables <- function(version = "5.3") {
 #' Required columns for a generated cohort set.
 #'
 #' @param table Either `cohort`, `cohort_set` or `cohort_attrition`
+#' @param required Whether to include only required fields.
 #' @param version Version of the OMOP Common Data Model.
 #'
+#' @return Character vector with the column names
+#'
 #' @return Required columns
 #'
 #' @export
@@ -771,10 +776,11 @@ cohortTables <- function(version = "5.3") {
 #' library(omopgenerics)
 #' cohortColumns("cohort")
 #' }
-cohortColumns <- function(table, version = "5.3") {
+cohortColumns <- function(table, required = TRUE, version = "5.3") {
   assertVersion(version = version)
   assertTable(table = table, version = version, type = "cohort")
-  requiredColumns(table = table, version = version, type = "cohort")
+  assertLogical(x = required, length = 1)
+  getColumns(table = table, version = version, type = "cohort", required = required)
 }
 
 #' Names of the tables that contain the results of achilles analyses
@@ -799,10 +805,11 @@ achillesTables <- function(version = "5.3"){
 #'
 #' @param table Table for which to see the required columns. One of
 #' "achilles_analysis", "achilles_results", or "achilles_results_dist".
+#' @param required Whether to include only required fields.
 #' @param version Version of the OMOP Common Data Model.
 #'
-#' @return A vector containing the names of columns for the given
-#' achilles result table
+#' @return Character vector with the column names
+#'
 #' @export
 #'
 #' @examples
@@ -812,10 +819,11 @@ achillesTables <- function(version = "5.3"){
 #' achillesColumns("achilles_results")
 #' achillesColumns("achilles_results_dist")
 #' }
-achillesColumns <- function(table, version = "5.3") {
+achillesColumns <- function(table, required = TRUE, version = "5.3") {
   assertVersion(version = version)
   assertTable(table = table, version = version, type = "achilles")
-  requiredColumns(table = table, version = version, type = "achilles")
+  assertLogical(x = required, length = 1)
+  getColumns(table = table, version = version, type = "achilles", required = required)
 }
 
 assertVersion <- function(version, call = parent.frame()) {
@@ -831,22 +839,22 @@ tableChoice <- function(version, type) {
   ] |>
     unique()
 }
-requiredColumns <- function(table, version, type) {
+getColumns <- function(table, version, type, required) {
   fieldsTables$cdm_field_name[
     grepl(version, fieldsTables$cdm_version) &
       fieldsTables$cdm_table_name == table &
-      fieldsTables$is_required == TRUE &
+      fieldsTables$is_required == required &
       fieldsTables$type == type
   ]
 }
 
 #' @export
 str.cdm_reference <- function(object, ...) {
-  src <- cdmSource(object)
-  mes <- glue::glue(
-    "A cdm reference of {cdmName(object)} with {length(object)} tables: {paste0(names(object), collapse = ', ')}"
-  )
-  cat(mes, sep = "")
+  res <- cli::cli_text(
+    "A cdm reference of {cdmName(object)} with {length(object)} table{?s}: {names(object)}."
+  ) |>
+    cli::cli_fmt()
+  cat(res)
 }
 
 #' Create an empty cdm_reference
